mysql.constants.client_flags

Package mysql :: Package constants :: Module client_flags |
[hide private]
[frames] | no frames]

# Module client_flags

Flags used for connecting to the server.

The flags in this module are used by the mysql.connection.Connection.connect method.

Variables | [hide private]
`` | COMPRESS = `32`
`` | FOUND_ROWS = `2`
`` | IGNORE_SPACE = `256`
`` | INTERACTIVE = `1024`
`` | LOCAL_FILES = `128`
`` | MULTI_RESULTS = `131072`
`` | MULTI_STATEMENTS = `65536`
`` | NO_SCHEMA = `16`
`` | ODBC = `64`
`` | SSL = `2048`
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### COMPRESS Value:
        32

    ### FOUND_ROWS Value:
        2

    ### IGNORE_SPACE Value:
        256

    ### INTERACTIVE Value:
        1024

    ### LOCAL_FILES Value:
        128

    ### MULTI_RESULTS Value:
        131072

    ### MULTI_STATEMENTS Value:
        65536

    ### NO_SCHEMA Value:
        16

    ### ODBC Value:
        64

    ### SSL Value:
        2048

    ### __version__ Value:
        '$Revision: 1.3 $'